#gabi_distribution
This package contains classes for Gaussian and Binomial distribution

What is Gaussian distribution?
In probability theory, a normal (or Gaussian or Gauss or Laplace–Gauss) distribution is a type of continuous probability distribution for a real-valued random variable. 

What is Binomial distribution?
In probability theory and statistics, the binomial distribution with parameters n and p is the discrete probability distribution of the number of successes in a sequence of n independent experiments, each asking a yes–no question, and each with its own boolean-valued outcome: success/yes/true/one (with probability p) or failure/no/false/zero (with probability q = 1 − p). A single success/failure experiment is also called a Bernoulli trial or Bernoulli experiment and a sequence of outcomes is called a Bernoulli process; for a single trial, i.e., n = 1, the binomial distribution is a Bernoulli distribution. The binomial distribution is the basis for the popular binomial test of statistical significance.

Files
Generaldistribution.py - This is the base class for the Gaussian and Binomial dostribution class
Gaussiandistribution.py - This is the class for Gaussian distribution
Binomialdistribution.py - This is the class for Binomial distribution

Installation 
Type the following command into your terminal 
pip install gabi_distribution